@@ -21,11 +21,8 @@
 
 extern const char *grecs_preprocessor;
 
-size_t grecs_preproc_fill_buffer(char *buf, size_t size);
 void grecs_preproc_add_include_dir(char *dir);
-int grecs_preproc_init(const char *name);
-void grecs_preproc_done(void);
-int grecs_preproc_run(const char *config_file, const char *extpp);
+int grecs_preprocess(char const *name, int trace);
 
 #define GRECS_STD_INCLUDE 0x01
 #define GRECS_USR_INCLUDE 0x02
@@ -37,7 +34,7 @@ int grecs_foreach_include_dir(int flag, int (*fun)(int, const char *, void *),
 char *grecs_find_include_file(const char *name, int allow_cwd);
 
 FILE *grecs_preproc_extrn_start(const char *file, pid_t *ppid);
-void grecs_preproc_extrn_shutdown(pid_t pid);
+int grecs_preproc_extrn_shutdown(pid_t pid);
 
 void grecs_include_path_clear(void);
 void grecs_include_path_setup(const char *dir, ...);
